@@ -17,12 +17,12 @@ from rich.padding import Padding
 
 
 # TODO remove
-import conda_build.jinja_context
 from conda.base.context import context
 from conda_build.config import get_or_merge_config
 from conda_build.utils import apply_pin_expressions
 from conda.models.channel import Channel as CondaChannel
 from conda_build.metadata import eval_selector, ns_cfg
+from conda_build.jinja_context import native_compiler
 
 from boa.core.config import boa_config
 
@@ -170,6 +170,7 @@ class Output:
         self.version = d["package"]["version"]
         self.build_string = d["package"].get("build_string")
         self.build_number = d["build"].get("number", 0)
+        self.noarch = d["build"].get("noarch", False)
         self.is_first = False
         self.sections = {}
 
@@ -305,7 +306,12 @@ class Output:
         for idx, r in enumerate(self.requirements["build"]):
             if r.name.startswith("COMPILER_"):
                 lang = r.splitted[1].lower()
-                compiler = conda_build.jinja_context.compiler(lang, self.config)
+                if variant.get(lang + "_compiler"):
+                    compiler = (
+                        f"{variant[lang + '_compiler']}_{variant['target_platform']}"
+                    )
+                else:
+                    compiler = f"{native_compiler(lang, copied.config)}_{variant['target_platform']}"
                 if variant.get(lang + "_compiler_version"):
                     version = variant[lang + "_compiler_version"]
                     copied.requirements["build"][idx].final = f"{compiler} {version}*"
@@ -331,6 +337,7 @@ class Output:
             "version": self.version,
             "build_number": self.build_number,
             "source": self.data["source"],
+            "noarch": self.noarch,
         }
 
         res["differentiating_variant"] = self.differentiating_variant
@@ -547,21 +554,28 @@ class Output:
 
         if env == "build":
             for rex in collected_run_exports:
-                if "strong" in rex:
-                    for r in rex["strong"]:
+                if not self.noarch:
+                    for r in rex.get("strong", []):
                         append_or_replace("host", r)
                         append_or_replace("run", r)
-                if "weak" in rex:
-                    for r in rex["weak"]:
+                    for r in rex.get("weak", []):
                         append_or_replace("host", r)
+                    for r in rex.get("strong_constrains", []):
+                        append_or_replace("run_constrained", r)
 
         if env == "host":
             for rex in collected_run_exports:
-                if "strong" in rex:
-                    for r in rex["strong"]:
+                if not self.noarch:
+                    for r in rex.get("strong", []):
                         append_or_replace("run", r)
-                if "weak" in rex:
-                    for r in rex["weak"]:
+                    for r in rex.get("weak", []):
+                        append_or_replace("run", r)
+                    for r in rex.get("strong_constrains", []):
+                        append_or_replace("run_constrained", r)
+                    for r in rex.get("weak_constrains", []):
+                        append_or_replace("run_constrained", r)
+                else:
+                    for r in rex.get("noarch", []):
                         append_or_replace("run", r)
 
     def _solve_env(self, env, all_outputs):
