@@ -16,7 +16,6 @@ from conda.base.context import context
 from conda.plan import get_blank_actions
 from conda.models.dist import Dist
 from conda_build.conda_interface import pkgs_dirs
-from conda.models.channel import Channel
 from conda.core.package_cache_data import PackageCacheData
 
 from mamba import mamba_api
@@ -46,6 +45,16 @@ def get_solver(subdir):
     return solver_cache[subdir], pkg_cache
 
 
+def get_url_from_channel(c):
+    if c.startswith("file://"):
+        # The conda functions (specifically remove_auth) assume the input
+        # is a url; a file uri on windows with a drive letter messes them
+        # up.
+        return c
+    else:
+        return split_anaconda_token(remove_auth(c))[0]
+
+
 def to_action(specs_to_add, specs_to_remove, prefix, to_link, to_unlink, index):
     to_link_records = []
 
@@ -53,14 +62,16 @@ def to_action(specs_to_add, specs_to_remove, prefix, to_link, to_unlink, index):
     final_precs = IndexedSet(prefix_data.iter_records())
 
     lookup_dict = {}
-    for _, c in index:
-        lookup_dict[Channel(c).url(with_credentials=False)] = c
+    for _, entry in index:
+        lookup_dict[
+            entry["channel"].platform_url(entry["platform"], with_credentials=False)
+        ] = entry
 
     assert len(to_unlink) == 0
 
     for c, pkg, jsn_s in to_link:
-        sdir = lookup_dict[split_anaconda_token(remove_auth(c))[0]]
-        rec = to_package_record_from_subjson(sdir, pkg, jsn_s)
+        entry = lookup_dict[get_url_from_channel(c)]
+        rec = to_package_record_from_subjson(entry, pkg, jsn_s)
         final_precs.add(rec)
         to_link_records.append(rec)
 
@@ -135,15 +146,24 @@ class MambaSolver:
             if not subdir.loaded():
                 continue
 
+            # support new mamba
+            if isinstance(channel, dict):
+                channelstr = channel["url"]
+                channelurl = channel["url"]
+            else:
+                channelstr = str(channel)
+                channelurl = channel.url(with_credentials=True)
+
             cp = subdir.cache_path()
             if cp.endswith(".solv"):
                 os.remove(subdir.cache_path())
                 cp = cp.replace(".solv", ".json")
 
-            self.local_repos[str(channel)] = mamba_api.Repo(
-                self.pool, str(channel), cp, channel.url(with_credentials=True)
+            self.local_repos[channelstr] = mamba_api.Repo(
+                self.pool, channelstr, cp, channelurl
             )
-            self.local_repos[str(channel)].set_priority(start_prio, 0)
+
+            self.local_repos[channelstr].set_priority(start_prio, 0)
             start_prio -= 1
 
     def solve(self, specs, pkg_cache_path=None):
@@ -177,7 +197,7 @@ class MambaSolver:
             pstring = "\n".join(["   " + el for el in pstring.split("\n")])
             error_string += f"\nThe reported errors are:\n{pstring}"
             print(error_string)
-            exit(1)
+            raise RuntimeError("Solver could not find solution.")
 
         if pkg_cache_path is None:
             # use values from conda
